pub struct TarRegularFile<'a, R> { /* private fields */ }Expand description
Implementations
Sourceimpl<'a, R: AsyncRead + 'a> TarRegularFile<'a, R>
impl<'a, R: AsyncRead + 'a> TarRegularFile<'a, R>
Sourcepub fn new<N: Into<Box<str>>>(
path_name: N,
size: u64,
inner: R,
) -> TarRegularFile<'a, R>
pub fn new<N: Into<Box<str>>>( path_name: N, size: u64, inner: R, ) -> TarRegularFile<'a, R>
Build a regular-file entry with the provided body reader.
size must match the exact number of bytes that inner will yield.
Sourcepub fn mtime(&self) -> SystemTime
pub fn mtime(&self) -> SystemTime
Return the modification time stored for this entry.
Sourcepub fn atime(&self) -> Option<SystemTime>
pub fn atime(&self) -> Option<SystemTime>
Return the access time stored for this entry, if present.
Sourcepub fn ctime(&self) -> Option<SystemTime>
pub fn ctime(&self) -> Option<SystemTime>
Return the status-change time stored for this entry, if present.
Sourcepub fn uname(&self) -> &str
pub fn uname(&self) -> &str
Return the symbolic user name stored in the tar header, if present.
Sourcepub fn with_uname<S: Into<Box<str>>>(self, name: S) -> Self
pub fn with_uname<S: Into<Box<str>>>(self, name: S) -> Self
Replace the symbolic user name stored in the tar header.
Sourcepub fn gname(&self) -> &str
pub fn gname(&self) -> &str
Return the symbolic group name stored in the tar header, if present.
Sourcepub fn with_gname<S: Into<Box<str>>>(self, name: S) -> Self
pub fn with_gname<S: Into<Box<str>>>(self, name: S) -> Self
Replace the symbolic group name stored in the tar header.
Sourcepub fn with_mode(self, mode: u32) -> Self
pub fn with_mode(self, mode: u32) -> Self
Replace the raw permission bits stored in the tar header.
Sourcepub fn with_mtime(self, mtime: SystemTime) -> Self
pub fn with_mtime(self, mtime: SystemTime) -> Self
Replace the modification time stored for this entry.
Sourcepub fn with_atime(self, atime: SystemTime) -> Self
pub fn with_atime(self, atime: SystemTime) -> Self
Replace the access time stored for this entry.
Sourcepub fn with_ctime(self, ctime: SystemTime) -> Self
pub fn with_ctime(self, ctime: SystemTime) -> Self
Replace the status-change time stored for this entry.
Sourcepub fn attrs(&self) -> &AttrList
pub fn attrs(&self) -> &AttrList
Return the extended attributes that will be encoded in PAX records.
Sourcepub fn attrs_mut(&mut self) -> &mut AttrList
pub fn attrs_mut(&mut self) -> &mut AttrList
Return a mutable reference to the extended attributes.
Sourcepub fn with_attrs(self, attrs: AttrList) -> Self
pub fn with_attrs(self, attrs: AttrList) -> Self
Replace the extended-attribute list and return the updated entry.